==> xsns_1.0.1.zip: xsns_1.0.1/xoops_trust_path/modules/xsns/act/member/sub_admin_execAction.php <==
<?php
class sub_admin_execAction extends memberAction
{

function dispatch(&$context)
{
	global $xoopsUser, $xoopsUserIsAdmin;
	
	if($this->isGuest() || !$this->validateToken('MEMBER_EDIT')){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	$own_uid = $xoopsUser->getVar('uid');
	
	$cid = $this->getIntRequest('cid');
	$uid = $this->getIntRequest('uid');
	$message = $this->getTextRequest('message');
	
	if(!$cid || !$uid || $uid == $own_uid){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	
	// ߥ˥ƥμ
	$perm = _CM_AUTH_XOOPS_ADMIN | _CM_AUTH_ADMIN;
	$commu_handler =& CM_CommunityHandler::getInstance();
	$community =& $commu_handler->get($cid);
	if(!is_object($community) || !$community->checkAuthority($perm)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	
	if($xoopsUserIsAdmin && $own_uid != $community->getVar('uid_admin')){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	
	// оݥߥ˥ƥСμ
	$c_member_handler =& CM_MemberHandler::getInstance();
	$c_member =& $c_member_handler->get($cid, $uid);
	if(!is_object($c_member)){
		redirect_header(_CM_URL_COMMU, 2, _NOPERM);
	}
	$c_member_info =& $c_member->getInfo();
	
	// ¸ΰʽʣɤ
	$confirm_handler =& CM_ConfirmHandler::getInstance();
	$criteria = new CriteriaCompo(new Criteria('c_commu_id', $cid));
	$criteria->add(new Criteria('uid_from', $own_uid));
	$criteria->add(new Criteria('uid_to', $uid));
	$criteria->add(new Criteria('mode', '(1,2)', 'IN'));	// Ը or ԽǤ
	$confirm_handler->deleteObjects($criteria);
	
	// 
	$confirm =& $confirm_handler->create();
	$confirm->setVars(array(
		'c_commu_id' => $cid,
		'uid_from' => $own_uid,
		'uid_to' => $uid,
		'mode' => 2,	// ԽǤ
		'r_datetime' => date('Y-m-d H:i:s'),
		'message' => $message,
	));
	
	if($confirm_handler->insert($confirm)){
		redirect_header('?cid='.$cid, 2, 
						sprintf(_CM_MEMBER_SUB_ADMIN_OK, $c_member_info['name']));
	}
	redirect_header(_CM_URL_COMMU, 2, _CM_MEMBER_SUB_ADMIN_NG);
}

}
?>

==> xsns_1.1.0.zip: xsns_1.1.0/xoops_trust_path/modules/xsns/act/member/sub_admin_execAction.php <==
<?php
class Xsns_Sub_admin_exec_Action extends Xsns_Member_Action
{

function dispatch()
{
	global $xoopsUser, $xoopsUserIsAdmin;
	
	if($this->isGuest() || !$this->validateToken('MEMBER_EDIT')){
		redirect_header(XOOPS_URL, 2, _NOPERM);
	}
	$own_uid = $xoopsUser->getVar('uid');
	
	$cid = $this->getIntRequest('cid');
	$uid = $this->getIntRequest('uid');
	$message = $this->getTextRequest('message');
	
	if(!$cid || !$uid || $uid == $own_uid){
		redirect_header(XOOPS_URL, 2, _NOPERM);
	}
	
	// ߥ˥ƥμ
	$perm = XSNS_AUTH_XOOPS_ADMIN | XSNS_AUTH_ADMIN;
	$commu_handler =& XsnsCommunityHandler::getInstance();
	$community =& $commu_handler->get($cid);
	if(!is_object($community) || !$community->checkAuthority($perm)){
		redirect_header(XOOPS_URL, 2, _NOPERM);
	}
	
	if($xoopsUserIsAdmin && $own_uid != $community->getVar('uid_admin')){
		redirect_header(XOOPS_URL, 2, _NOPERM);
	}
	
	// оݥߥ˥ƥСμ
	$c_member_handler =& XsnsMemberHandler::getInstance();
	$c_member =& $c_member_handler->getOne($cid, $uid);
	if(!is_object($c_member)){
		redirect_header(XOOPS_URL, 2, _NOPERM);
	}
	$c_member_info =& $c_member->getInfo();
	
	// ¸ΰʽʣɤ
	$confirm_handler =& XsnsConfirmHandler::getInstance();
	$criteria = new CriteriaCompo(new Criteria('c_commu_id', $cid));
	$criteria->add(new Criteria('uid_from', $own_uid));
	$criteria->add(new Criteria('uid_to', $uid));
	$criteria->add(new Criteria('mode', '(1,2)', 'IN'));	// Ը or ԽǤ
	$confirm_handler->deleteObjects($criteria);
	
	// 
	$confirm =& $confirm_handler->create();
	$confirm->setVars(array(
		'c_commu_id' => $cid,
		'uid_from' => $own_uid,
		'uid_to' => $uid,
		'mode' => 2,	// ԽǤ
		'r_datetime' => date('Y-m-d H:i:s'),
		'message' => $message,
	));
	
	if($confirm_handler->insert($confirm)){
		redirect_header('?cid='.$cid, 2, 
						sprintf(_MD_XSNS_MEMBER_SUB_ADMIN_OK, $c_member_info['name']));
	}
	redirect_header(XSNS_URL_COMMU, 2, _MD_XSNS_MEMBER_SUB_ADMIN_NG);
}

}
?>
